/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef UCQWARNINGS_H
#define UCQWARNINGS_H

#include <QtGui/QDialog>
#include "ui/ui_ucqwarnings.h"
#include <QTime>

/**
 * \class UCQWarnings
 * \brief Dialog with a read-only QTextEdit to display warnings, a clear and a
 *        close button.
 *
 * To add new warnings use the addWarning slot. When a new warning is added,
 * the newWarnings() signal is emitted.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see UCQStatusBar
 */
class UCQWarnings: public QDialog
{
Q_OBJECT

public:
    UCQWarnings ( QWidget* = 0 );

private:
    /**
     * \brief The Ui object.
     */
    Ui::UCQWarnings ui_;

public slots:
    void addWarning ( QString );
    void clear ();

signals:
    /**
     * \brief Signals that new warnings were added.
     */
    void newWarnings ();
};

#endif // UCQWARNINGS_H
